==> pandoc-2.18.tar.gz: pandoc-2.18/AUTHORS.md <==
# Contributors

- Aaron Wolen
- Agustín Martín Barbero
- Albert Krewinkel
- Alex Ivkin
- Alex Toldaiev
- Alex Vong
- Alexander Kondratskiy
- Alexander Krotov
- Alexander Sulfrian
- Alexander V Vershilov
- Alexandre Franke
- Alfred Wechselberger
- Amogh Rathore
- Anabra
- Anders Waldenborg
- Andreas Lööw
- Andrew Dunning
- Andy Morris
- Aner Lucero
- Anti-Distinctlyminty
- Antoine Latter
- Antonio Terceiro
- Arata Mizuki
- Arata Mizuki
- Arfon Smith
- Arfon Smith
- Arlo O'Keeffe
- Artyom Kazak
- B. Scott Michel
- Ben Firshman
- Ben Gamari
- Ben Steinberg
- Beni Cherniavsky-Paskin
- Benjamin Bray
- Benoit Schweblin
- Benson Muite
- Bjorn Buckwalter
- Blake Eryx
- Bodigrim
- Bradley Kuhn
- Brent Yorgey
- Brian Leung
- Bryan O'Sullivan
- Caleb McDaniel
- Caleb Mclennan
- Calvin Beck
- Carlos Sosa
- Carsten Allefeld
- Cécile Chemin
- Cédric Couralet
- Charanjit Singh
- Chris Black
- Christian Conkle
- Christian Despres
- Christoffer Ackelman
- Christoffer Sawicki
- Christophe Dervieux
- Clare Macrae
- Clint Adams
- Conal Elliott
- Cormac Relf
- Craig S. Bosma
- Damien Clochard
- Daniel Bergey
- Daniel Maslowski
- Daniel T. Staal
- Daniele D'Orazio
- David A Roberts
- David Lazar
- David Martschenko
- David Röthlisberger
- Denis Laxalde
- Denis Maier
- Derek Chen-Becker
- Diego Balseiro
- Dimitri Sabadie
- Dimitris Apostolou
- Dmitry Pogodin
- Dmitry Volodin
- Douglas Calvert
- Eigil Rischel
- Emanuel Evans
- Emerson Harkin
- Emily Bourke
- Emily Eisenberg
- Eric Kow
- Eric Schrijver
- Eric Seidel
- Erik Rask
- Ethan Riley
- Étienne Bersac
- Even Brenden
- Ezwal
- Fabián Heredia Montiel
- Félix Baylac-Jacqué
- Felix Yan
- Florian Beeres
- Florian Eitel
- Florian Klink
- Florian Kohrt
- Francesco Mazzoli
- Francesco Occhipinti
- François Gannaz
- Frederik Elwert
- Freiric Barral
- Freirich Raabe
- Frerich Raabe
- Fyodor Sheremetyev
- Gabor Pali
- Gavin Beatty
- Gottfried Haider
- Greg Maslov
- Greg Rundlett
- Grégory Bataille
- Guriy Samarin
- Gwern Branwen
- Hamish Mackenzie
- Hans-Peter Deifel
- Heiko Schlittermann
- Henrik Tramberend
- Henry de Valence
- Herwig Stuetz
- Hubert Plociniczak
- Ian Max Andolina
- Igor Khorlo
- Igor Pashev
- Ilya V. Portnov
- Ivan Trubach
- Ivar de Bruin
- Ivo Clarysse
- Jaap de Jong
- J. B. Rainsberger
- J. Lewis Muir
- Jaime Marquínez Ferrándiz
- Jake Zimmerman
- Jakob Voß
- James Aspnes
- Jamie F. Olson
- Jan Larres
- Jan Schulz
- Jan Tojnar
- Jannik Buhr
- Jan-Otto Kröpke
- Jared Lander
- Jason Ronallo
- Jeff Arnold
- Jeff Runningen
- Jens Getreu
- Jens Petersen
- Jesse Hathaway
- Jérémy Bobbio
- Jeroen de Haas
- Jerry Sky
- Jesse Rosenthal
- Joe Hermaszewski
- Joe Hillenbrand
- John KetzerX
- John Luke Bentley
- John MacFarlane
- John Muccigrosso
- Jonas Scholl
- Jonas Smedegaard
- Jonathan Daugherty
- Jonathan Dönszelmann
- Jose Luis Duran
- José de Mattos Neto
- Josef Svenningsson
- Joseph C. Sible
- Julien Cretel
- Julien Dutant
- Juliette Fourcot
- Juliusz Gonera
- Justin Bogner
- Karl Pettersson
- Keiichiro Shikano
- Kelsey Hightower
- Kolen Cheung
- Konstantin Zudov
- Kristof Bastiaensen
- Krystof Beuermann
- Lars-Dominik Braun
- Laurent P. René de Cotret
- Leif Metcalf
- Leonard Rosenthol
- Lila
- Loïc Grobol
- Lorenzo
- Lucas Escot
- Lucas Viana
- Lucas V. R
- Luke Plant
- Marc Schreiber
- Mario Lang
- Mark Szepieniec
- Mark Wright
- Martin Linn
- Masayoshi Takahashi
- Matej Kollar
- Mathias Schenner
- Mathias Walter
- Mathieu Boespflug
- Mathieu Duponchelle
- Matthew Doty
- Matthew Eddey
- Matthew Pickering
- Matthias C. M. Troffaes
- Mauro Bieg
- Max Bolingbroke
- Max Rydahl Andersen
- Merijn Verstraaten
- Michael Beaumont
- Michael Chladek
- Michael Hoffmann
- Michael Peyton Jones
- Michael Reed
- Michael Snoyman
- Michael Thompson
- Mike Tzou
- Milan Bracke
- MinRK
- Morton Fox
- Nathan Gass
- Naveen
- Neil Mayhew
- Nick Bart
- Nick Berendsen
- Nick Fleisher
- Nicolas Kaiser
- Nikolai Korobeinikov
- Nikolay Yakimov
- Nils Carlson
- Nixon Enraght-Moony
- Nokome Bentley
- OCzarnecki
- Ola Wolska
- Ole Martin Ruud
- Oliver Matthews
- Ophir Lifshitz
- Or Neeman
- OvidiusCicero
- Owen McGrath
- Pablo Rodríguez
- Pascal Wagler
- Paul Rivier
- Paul Tilley
- Paulo Tanimoto
- Pete Ryland
- Peter Fabinksi
- Peter Wang
- Philip Pesca
- Philippe Ombredanne
- Phillip Alday
- Prayag Verma
- Puneeth Chaganti
- Quinn
- Ralf Stephan
- Raniere Silva
- Raymond Ehlers
- Recai Oktaş
- Rowan Rodrik van der Molen
- Roland Hieber
- Roman Beránek
- RyanGlScott
- S.P.H
- Salim B
- Samuel Tardieu
- Saumel Lemmenmeier
- Sascha Wilde
- Scott Morrison
- Sebastian Talmon
- Sergei Trofimovich
- Sergey Astanin
- Shahbaz Youssefi
- Shaun Attfield
- Shim Myeongseob
- Shin Sang-jae
- Sidarth Kapur
- Sidharth Kapur
- Simon Hengel
- Simon Schuster
- Stefan Dresselhaus
- Sumit Sahrawat
- TEC
- Tarik Graba
- Tatiana Porras
- Thenaesh Elango
- Thomas Hodgson
- Thomas Weißschuh
- Tim Lin
- Tim Wisotzki
- Timm Albers
- Timothy Humphries
- Tiziano Müller
- Todd Sifleet
- Tom Leese
- Tristan Stenner
- Tristan de Cacqueray
- Tuong Nguyen Manh
- Uli Köhler
- Urs Liska
- Václav Haisman
- Václav Zeman
- Vaibhav Sagar
- Vanessa McHale
- Vasily Alferov
- Veratyr
- Viktor Kronvall
- Vincent
- Vlad Hanciuta
- Waldir Pimenta
- Wandmalfarbe
- Wikiwide
- William Lupton
- Winnie Hellmann
- Xavier Olive
- Yan Pashkovsky
- Yoan Blanc
- Yuchen Pei
- Zihang Chen
- a-vrma
- andrebauer
- argent0
- badumont
- blmage
- bucklereed
- bumper314
- chinapedia
- cholonam
- csforste
- d-dorazio
- damon-sava-stanley
- dbecher-ito
- ebiim
- favonia
- hseg
- infinity0x
- jeongminkim-islab
- kaizshang91
- lux-lth
- lwolfsonkin
- mbrackeantidot
- mjfs
- mt_caret
- niszet
- nkalvi
- nuew
- obcat
- oltolm
- oquechy
- qerub
- quasicomputational
- ricnorr
- robabla
- roblabla
- rodja.trappe
- rski
- shreevatsa.public
- takahashim
- taotieren
- tecosaur
- tgkokk
- the-solipsist
- thsutton
- timo-a
- vijayphoenix
- wiefling
- willj-dev
- wuffi

==> pandoc-3.1.8.tar.gz: pandoc-3.1.8/AUTHORS.md <==
# Contributors

- Aaron Wolen
- Adelar da Silva Queiróz
- Agustín Martín Barbero
- Akos Marton
- Albert Krewinkel
- Alex Ivkin
- Alex Toldaiev
- Alex Vong
- Alexander Batischev
- Alexander Kondratskiy
- Alexander Krotov
- Alexander Sulfrian
- Alexander V Vershilov
- Alexandre Franke
- Alfred Wechselberger
- Amar Al-Zubaidi
- Amir Dekel
- Amneesh Singh
- Amogh Rathore
- Amy de Buitléir
- Anabra
- Anders Waldenborg
- Andreas Lööw
- Andreas Scherer
- Andres Freund
- Andrew Dunning
- Andy Morris
- Aner Lucero
- Anti-Distinctlyminty
- Antoine Latter
- Antonio Terceiro
- Arata Mizuki
- Arata Mizuki
- Arfon Smith
- Arlo O'Keeffe
- Artem Pelenitsyn
- Artyom Kazak
- B. Scott Michel
- Bastien Dumont
- Ben Firshman
- Ben Gamari
- Ben Steinberg
- Beni Cherniavsky-Paskin
- Benjamin Bray
- Benjamin Esham
- Benjamin Wuethrich
- Benoit Schweblin
- Benson Muite
- Bjorn Buckwalter
- Blake Eryx
- Bodigrim
- Bradley Kuhn
- Brent Yorgey
- Brian Leung
- Bryan O'Sullivan
- Caleb McDaniel
- Caleb Mclennan
- Calvin Beck
- Carlos Scheidegger
- Carlos Sosa
- Carsten Allefeld
- Castedo Ellerman
- Cécile Chemin
- Cédric Couralet
- Cezary Drożak
- Charanjit Singh
- Charlotte Koch
- Chris Black
- Christian Conkle
- Christian Christiansen
- Christian Despres
- Christoffer Ackelman
- Christoffer Sawicki
- Christophe Dervieux
- Clare Macrae
- Clint Adams
- Conal Elliott
- Cormac Relf
- Craig S. Bosma
- Damien Clochard
- Daniel Bergey
- Daniel Kessler
- Daniel Maslowski
- Daniel T. Staal
- Daniele D'Orazio
- David A Roberts
- David Lazar
- David Martschenko
- David Röthlisberger
- Denis Laxalde
- Denis Maier
- Derek Chen-Becker
- Diego Balseiro
- Diogo Almiro
- Dimitri Sabadie
- Dimitris Apostolou
- Dmitry Pogodin
- Dmitry Volodin
- Douglas Calvert
- Eigil Rischel
- Elliot Bobrow
- Emanuel Evans
- Emerson Harkin
- Emily Bourke
- Emily Eisenberg
- Eric Kow
- Eric Schrijver
- Eric Seidel
- Erik Rask
- Ethan Riley
- Étienne Bersac
- Even Brenden
- Ezwal
- Fabián Heredia Montiel
- Félix Baylac-Jacqué
- Felix Yan
- Florian Beeres
- Florian Eitel
- Florian Klink
- Florian Kohrt
- Francesco Mazzoli
- Francesco Occhipinti
- François Gannaz
- Frank Seifferth
- Frederik Elwert
- Freiric Barral
- Freirich Raabe
- Frerich Raabe
- Fyodor Sheremetyev
- Gabor Pali
- Gabriel Lewertowski
- Gavin Beatty
- Georgi Lyubenov
- Gottfried Haider
- Greg Maslov
- Greg Rundlett
- Grégory Bataille
- Guriy Samarin
- Gwern Branwen
- Hamish Mackenzie
- Hans-Peter Deifel
- Heiko Schlittermann
- Henrik Tramberend
- Henry de Valence
- Herwig Stuetz
- Hos Es
- Hubert Plociniczak
- Ian Max Andolina
- Igor Khorlo
- Igor Pashev
- Ilona Silverwood
- Ilya V. Portnov
- Ivan Panchenko
- Ivan Trubach
- Ivar de Bruin
- Ivo Clarysse
- Jaap de Jong
- J. B. Rainsberger
- J. Lewis Muir
- Jackson Schuster
- Jaehwang Jung
- Jaime Marquínez Ferrándiz
- Jake Zimmerman
- Jakob Voß
- James Aspnes
- James Scott-Brown
- Jamie F. Olson
- Jan Larres
- Jan Schulz
- Jan Tojnar
- Jannik Buhr
- Jan-Otto Kröpke
- Jared Lander
- Jason Ronallo
- Jeff Arnold
- Jeff Runningen
- Jens Getreu
- Jens Petersen
- Jesse Hathaway
- Jeremie Knuesel
- Jérémy Bobbio
- Jeroen de Haas
- Jerry Sky
- Jesse Rosenthal
- Joe Hermaszewski
- Joe Hillenbrand
- John KetzerX
- John Luke Bentley
- John MacFarlane
- John Muccigrosso
- Jonas Scholl
- Jonas Smedegaard
- Jonathan Daugherty
- Jonathan Dönszelmann
- Jose Luis Duran
- José de Mattos Neto
- Josef Svenningsson
- Joseph C. Sible
- Julia Diaz
- Julien Cretel
- Julien Dutant
- Juliette Fourcot
- Juliusz Gonera
- Justin Bogner
- Justin Wood
- Karl Pettersson
- Keiichiro Shikano
- Kelsey Hightower
- Kevin Broch
- Kolen Cheung
- Konstantin Zudov
- Kristof Bastiaensen
- Krystof Beuermann
- Lars-Dominik Braun
- Laurent P. René de Cotret
- Leif Metcalf
- Leonard Rosenthol
- Lila
- Link Swanson
- Loïc Grobol
- Lorenzo
- Lucas Escot
- Lucas Viana
- Lucas V. R
- Luke Plant
- Marc Schreiber
- Marcin Serwin
- Mario Lang
- Mark Szepieniec
- Mark Wright
- Martin Joerg
- Martin Linn
- Martín Pozo
- Masataka Ogawa
- Masayoshi Takahashi
- Matej Kollar
- Mathias Schenner
- Mathias Walter
- Mathieu Boespflug
- Mathieu Duponchelle
- Matt Dodson
- Matthew Doty
- Matthew Eddey
- Matthew Pickering
- Matthias C. M. Troffaes
- Mauro Bieg
- Max Bolingbroke
- Max Rydahl Andersen
- Merijn Verstraaten
- Michael Beaumont
- Michael Chladek
- Michael Hoffmann
- Michael Peyton Jones
- Michael Reed
- Michael Snoyman
- Michael Stahl
- Michael Thompson
- Mike Tzou
- Mikołaj Machowski
- Milan Bracke
- MinRK
- Morgan Willcock
- Morton Fox
- Nathan Gass
- Naveen
- Neil Mayhew
- Nick Bart
- Nick Berendsen
- Nick Fleisher
- Nicolas Kaiser
- Nikolai Korobeinikov
- Nikolay Yakimov
- Nils Carlson
- Nixon Enraght-Moony
- Noah Malmed
- Nokome Bentley
- Norwid Behrnd
- OCzarnecki
- Ola Wolska
- Ole Martin Ruud
- Oliver Matthews
- Olivier Benz
- Ophir Lifshitz
- Or Neeman
- OvidiusCicero
- Owen McGrath
- Pablo Rodríguez
- Pascal Wagler
- Paul Rivier
- Paul Tilley
- Paulo Tanimoto
- Pavol Otto
- Per Christian Gaustad
- Pete Ryland
- Peter Fabinksi
- Peter Wang
- Philip Pesca
- Philippe Ombredanne
- Phillip Alday
- Pranesh Prakash
- Prat
- Prayag Verma
- Puneeth Chaganti
- Quinn
- R. N. West
- Ralf Stephan
- Raniere Silva
- Raymond Ehlers
- Recai Oktaş
- Rowan Rodrik van der Molen
- Roland Hieber
- Roman Beránek
- Ruqi
- RyanGlScott
- S.P.H
- Salim B
- Sam S. Almahri
- Samuel Tardieu
- Saumel Lemmenmeier
- Sascha Wilde
- Scott Morrison
- Sebastian Talmon
- Sergei Trofimovich
- Sergey Astanin
- Shahbaz Youssefi
- Shaun Attfield
- Shim Myeongseob
- Shin Sang-jae
- Sidarth Kapur
- Sidharth Kapur
- Simon Hengel
- Simon Schuster
- Siphalor
- Stefan Dresselhaus
- Stephan Meijer
- Stephen Altamirano
- Sukil Etxenike
- Sukka
- Sumit Sahrawat
- Sven Wick
- TEC
- Tarik Graba
- Tatiana Porras
- Terence Eden
- Thenaesh Elango
- Thomas Hodgson
- Thomas Weißschuh
- Tim Lin
- Tim Wisotzki
- Timm Albers
- Timothy Humphries
- Tiziano Müller
- Todd Sifleet
- TomBen
- Tom Leese
- Toni Dietze
- Tristan Stenner
- Tristan de Cacqueray
- Tuong Nguyen Manh
- Uli Köhler
- Urs Liska
- Václav Haisman
- Václav Zeman
- Vaibhav Sagar
- Vanessa McHale
- Vasily Alferov
- Veratyr
- Viktor Kronvall
- Vincent
- Vlad Hanciuta
- Vladimir Alexiev
- Waldir Pimenta
- Wandmalfarbe
- Wentao Han
- Wikiwide
- William Lupton
- William Rusnack
- Winnie Hellmann
- Wout Gevaert
- Xavier Olive
- Yan Pashkovsky
- YI
- Yoan Blanc
- Yuchen Pei
- Zihang Chen
- arcnmx
- a-vrma
- andrebauer
- black-desk
- blmage
- bucklereed
- bumper314
- chinapedia
- cholonam
- csforste
- d-dorazio
- damon-sava-stanley
- dbecher-ito
- ebiim
- ech0
- favonia
- harabat
- hseg
- infinity0x
- jeongminkim-islab
- kaizshang91
- lifeunleaded
- lux-lth
- luz paz
- lwolfsonkin
- mbrackeantidot
- mjfs
- mt_caret
- nbehrnd
- niszet
- nkalvi
- nuew
- obcat
- oltolm
- oquechy
- pacien
- perro tuerto
- qerub
- quasicomputational
- ricnorr
- robabla
- roblabla
- rodja.trappe
- rski
- sdhoward
- shreevatsa.public
- takahashim
- taotieren
- tecosaur
- tgkokk
- the-solipsist
- thsutton
- thron7
- timo-a
- vijayphoenix
- vkraven
- wgevaert
- wiefling
- willj-dev
- wuffi
